Fits a C-SVC support vector machine with a Platt SMO solver. With two
classes this uses the validated binary path. With three or more classes, the
function fits one binary SVM for each class pair and predicts by majority
vote. Multiclass ties are resolved by choosing the class that appears first
in the factor level order.